pub struct DigitalDrawingCommands {
pub drawing_type: DigitalDrawingType,
pub values: Vec<(f32, DrawnRegion)>,
}Expand description
List of values to draw for a variable. It is an ordered list of values that should be drawn at the start time until the start time of the next value
Fields
drawing_type: DigitalDrawingTypevalues: Vec<(f32, DrawnRegion)>Implementations
Sourceimpl DigitalDrawingCommands
impl DigitalDrawingCommands
pub fn new_from_variable_info(info: &VariableInfo) -> Self
pub fn push(&mut self, val: (f32, DrawnRegion))